@@ -1,26 +1,27 @@
-import os
-import requests
-import tempfile
 from hashlib import sha256
 from packaging import version
 import pkg_resources
 from jsonschema import validate
 import json
 from distlib.index import PackageIndex
-from distlib.locators import PyPIJSONLocator
 from pathlib import Path
 #using pip directly https://pip.pypa.io/en/latest/reference/pip_install/#git
-from pytablewriter import MarkdownTableWriter, RstSimpleTableWriter
+from pytablewriter import MarkdownTableWriter
 from yawrap import Doc
-from pymodaq.daq_utils import daq_utils as utils
 import requests
 from lxml import html
 from copy import deepcopy
 import re
 
-pypi_index = PackageIndex()
-logger = utils.set_logger('plugin_manager', add_handler=False, base_logger=False, add_to_console=True)
+try:
+    from pymodaq.daq_utils import daq_utils as utils
+    logging = True
+    logger = utils.set_logger('plugin_manager', add_handler=False, base_logger=False, add_to_console=True)
 
+except ImportError:
+    logging = False
+
+pypi_index = PackageIndex()
 
 def find_dict_in_list_from_key_val(dicts, key, value):
     """ lookup within a list of dicts. Look for the dict within the list which has the correct key, value pair
@@ -42,8 +43,20 @@ def find_dict_in_list_from_key_val(dicts, key, value):
                 return dict
     return None
 
+
 def get_pypi_package_list(match_name=None):
+    status = 'Connecting to the pypi repository, may take some time to retrieve the list'
+    if logging:
+        logger.info(status)
+    else:
+        print(status)
     simple_package = requests.get('https://pypi.org/simple/')
+    if simple_package.status_code == 503:
+        info = 'The service from pypi is currently unavailable, please retry later or install your plugins manually'
+        if logging:
+            logger.info(info)
+        else:
+            print(info)
     tree = html.fromstring(simple_package.text)
     packages = []
     for child in tree.body:
@@ -51,6 +64,7 @@ def get_pypi_package_list(match_name=None):
             packages.append(child.text)
     return packages
 
+
 def get_pypi_pymodaq(package_name='pymodaq-plugins'):
     metadata = None
     rep = requests.get(f'https://pypi.python.org/pypi/{package_name}/json')
@@ -107,26 +121,31 @@ def get_plugin(name, entry='display-name'):
     d = find_dict_in_list_from_key_val(plugins, entry, name)
     return d
 
+
 def get_check_repo(plugin_dict):
     try:
         response = requests.get(plugin_dict["repository"])
     except requests.exceptions.RequestException as e:
-        logger.exception(str(e))
-        return str(e)
+        if logging:
+            logger.exception(str(e))
+            return str(e)
 
     if response.status_code != 200:
         rep = f'{plugin_dict["display-name"]}: failed to download plugin. Returned code {response.status_code}'
-        logger.error(rep)
+        if logging:
+            logger.error(rep)
         return rep
 
     # Hash it and make sure its what is expected
     hash = sha256(response.content).hexdigest()
     if plugin_dict["id"].lower() != hash.lower():
         rep = f'{plugin_dict["display-name"]}: Invalid hash. Got {hash.lower()} but expected {plugin_dict["id"]}'
-        logger.error(rep)
+        if logging:
+            logger.error(rep)
         return rep
     else:
-        logger.info(f'SHA256 is Ok')
+        if logging:
+            logger.info(f'SHA256 is Ok')
 
 
 def get_plugins(from_json=False, browse_pypi=True):
@@ -147,6 +166,7 @@ def get_plugins(from_json=False, browse_pypi=True):
     plugins_installed: list of already installed plugins
     plugins_update: list of plugins with existing update
     """
+    logger.info('Fetching plugin list')
     if from_json:
         plugins_available = get_plugins_from_json()
     else:
@@ -184,14 +204,16 @@ def validate_json_plugin_list():
 
 
 def post_error(message):
-    logger.error(message)
+    if logging:
+        logger.error(message)
 
 
 def check_plugin_entries():
     displaynames = []
     repositories = []
     for plugin in get_plugins_from_json():
-        logger.info(f'Checking info on plugin: {plugin["display-name"]}')
+        if logging:
+            logger.info(f'Checking info on plugin: {plugin["display-name"]}')
 
         try:
             response = requests.get(plugin["repository"])
@@ -208,7 +230,8 @@ def check_plugin_entries():
         if plugin["id"].lower() != hash.lower():
             post_error(f'{plugin["display-name"]}: Invalid hash. Got {hash.lower()} but expected {plugin["id"]}')
         else:
-            logger.info(f'SHA256 is Ok')
+            if logging:
+                logger.info(f'SHA256 is Ok')
 
         # check uniqueness of json display-name and repository
         found = False
@@ -228,6 +251,25 @@ def check_plugin_entries():
             repositories.append(plugin["repository"])
 
 
+def extract_authors_from_description(description):
+    """returns the authors as a list from the plugin package description (it should follow the template structure)
+
+    Parameters
+    ----------
+    description: (str)
+
+    Returns
+    -------
+    list of string
+    """
+
+    posa = description.find('Authors')
+    posc = description.find('\n\nContributors')
+    posi = description.find('\n\nInstruments')
+    authors_raw = description[posa:posc if posc != -1 else posi]
+    return authors_raw.split('\n* ')[1:]
+
+
 def write_plugin_doc():
     plugins = get_pypi_plugins(browse_pypi=True)
     base_path = Path(__file__).parent
@@ -244,9 +286,12 @@ def write_plugin_doc():
             if k == 'display-name':
                 tmp.append(f'<a href="{plug["homepage"]}" target="_top">{plug["display-name"]}</a> ')
             elif k == 'authors':
+                authors = extract_authors_from_description(plug['description'])
+                if len(authors) == 0:
+                    authors == plug[k]
                 doc, tag, text = Doc().tagtext()
                 with tag('ul'):
-                    for auth in plug[k]:
+                    for auth in authors:
                         with tag('li'):
                             text(auth)
                 tmp.append(doc.getvalue())
